#
# spec file for package stackit-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name stackit

Name:           stackit-cli
Version:        0.36.0
Release:        1.1
Summary:        A command-line interface to manage STACKIT resources
License:        Apache-2.0
URL:            https://github.com/stackitcloud/stackit-cli/
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  dos2unix
BuildRequires:  fish
BuildRequires:  go >= 1.24
BuildRequires:  zsh
Provides:       stackit = %{version}

%description
Welcome to the STACKIT CLI, a command-line interface for STACKIT - The German
business cloud.

The STACKIT CLI allows you to manage your STACKIT services and resources as
well as perform operations using the command-line or in scripts or automation,
such as:

* Projects, including permissions
* STACKIT Kubernetes Engine clusters
* Servers
* DNS zones and record-sets
* Databases such as PostgreSQL Flex, MongoDB Flex and SQLServer Flex

This CLI is in a BETA state. More services and functionality will be supported
soon. Your feedback is appreciated!

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags=" \
   -X main.version=%{version} \
   -X main.date=${BUILD_DATE}" \
   -o bin/%{executable_name}

dos2unix README.md

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%check
%{buildroot}/%{_bindir}/%{executable_name} --version
%{buildroot}/%{_bindir}/%{executable_name} --version | grep %{version}

%files
%doc README.md
%license LICENSE.md
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Tue Jul  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.36.0:
  * feat(ske): Region adjustment (#842)
  * fix(image): update overwrites nullable values (#834)
  * chore: update code owners (#840)
  * fix(deps): update stackit sdk modules (#838)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/mongodbflex
    (#832)
* Tue Jul  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.35.0:
  * chore(deps): update renovatebot/github-action action to v43.0.2
    (#829)
  * chore(deps): bump renovatebot/github-action from 43.0.1 to
    43.0.2 (#828)
  * fix(deps): update stackit sdk modules (#826)
  * Add installation instructions for rpm packages (#827)
  * fix: replaced deprecated brews config in goreleaser (#811)
  * feat(cli): onboard iaas snapshot api (#774)
  * chore(deps): update renovatebot/github-action action to v43.0.1
    (#822)
  * fix(deps): update stackit sdk modules (#810)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/dns (#815)
  * chore(deps): update renovatebot/github-action action to v43
    (#819)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/mongodbflex
    (#805)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/opensearch
    (#806)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/git (#807)
  * chore(deps): bump fgrosse/go-coverage-report from 1.1.1 to
    1.2.0 (#809)
* Tue Jun 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.34.5 (there are no releases between 0.33.1
  and this one):
  * fix(ci): fix goreleaser post-hooks (#808)
  * fix(ci): increase keychain timeout for release workflow (#804)
  * feat: add test coverage comment (#802)
  * feat(cli): onboard iaas volume backup api  (#773)
  * fix(ci): split goreleaser post hook into multiple steps (#803)
  * chore(deps): bump renovatebot/github-action from 42.0.5 to
    42.0.6 (#800)
  * fix(iaas): prevent nil pointer dereference on empty volume name
    (#799)
  * fix(deps): update stackit sdk modules (#796)
  * refactor(cli): add ConvertStringMapToInterfaceMap util function
    (#790)
  * fix(cli): List mongodb storages returns empty result  (#778)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/ske (#793)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/loadbalancer
    (#792)
  * chore(deps): update renovatebot/github-action action to v42.0.5
    (#788)
  * fix(deps): update module github.com/lmittmann/tint to v1.1.2
    (#785)
  * chore(deps): update module golang.org/x/tools to v0.34.0 (#783)
  * fix(deps): update module golang.org/x/text to v0.26.0 (#784)
  * chore(deps): bump golang.org/x/mod from 0.24.0 to 0.25.0 (#780)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/iaas (#781)
  * fix(deps): update stackit sdk modules (#779)
* Wed Jun  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.33.1 (0.33.0 was not released):
  * feat(ci): add check for goreleaser configuration (#766)
  * chore(deps): bump github.com/lmittmann/tint from 1.1.0 to 1.1.1
    (#769)
  * chore(deps): bump github.com/goccy/go-yaml from 1.17.1 to
    1.18.0 (#771)
  * fix(deps): update module github.com/goccy/go-yaml to v1.18.0
    (#772)
  * chore(deps): bump renovatebot/github-action from 42.0.3 to
    42.0.4 (#767)
  * chore(deps): update renovatebot/github-action action to v42.0.4
    (#768)
  * chore(deps): bump github.com/stackitcloud/stackit-sdk-go/core
    (#765)
  * fix(deps): update stackit sdk modules (#761)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/logme (#762)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/serviceaccount
    (#763)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/secretsmanager
    (#764)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/dns (#760)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/redis (#759)
  * fix(deps): update stackit sdk modules (#750)
  * chore(deps): update renovatebot/github-action action to v42.0.3
    (#757)
  * fix(deps): update module github.com/lmittmann/tint to v1.1.0
    (#758)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/mariadb (#753)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/rabbitmq (#754)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/mongodbflex
    (#755)
  * fix(deps): update module
    github.com/stackitcloud/stackit-sdk-go/services/ske to v0.22.4
    (#746)
  * fix(postgresql): Display correct error message when project id
    is not set (#745)
* Tue May 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.32.0:
  * fix panic in auth.TokenExpired (#736)
  * Add stackit git commands: list, describe, create and delete.
    (#725)
  * chore(deps): update renovatebot/github-action action to v42.0.2
    (#743)
  * feat(cli): set custom user-agent header for STACKIT API calls
    (#741)
  * fix(deps): update stackit sdk modules (#740)
  * refactor(cli): pass parameter struct to cmd factories (#735)
  * feat(fmt): run goimports on format make command (#733)
  * chore(deps): update module github.com/golangci/golangci-lint to
    v2 (#731)
  * feat: prettify json output using stackit curl (#713)
  * fix(deps): update module golang.org/x/term to v0.32.0 (#729)
  * fix(deps): update module golang.org/x/oauth2 to v0.30.0 (#728)
  * chore(deps): bump golang.org/x/oauth2 from 0.29.0 to 0.30.0
    (#727)
  * fix(deps): update module golang.org/x/text to v0.25.0 (#730)
  * chore(deps): update renovatebot/github-action action to v42
    (#732)
  * feat(deps): use go 1.24 tool feature to install golangci-lint
    (#709)
  * fix(deps): update module
    github.com/stackitcloud/stackit-sdk-go/services/mongodbflex to
    v1 (#724)
  * fix(deps): update stackit sdk modules (#721)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/observability
    (#718)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/ske (#722)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/secretsmanager
    (#723)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/mariadb (#719)
  * chore(deps): bump
    github.com/stackitcloud/stackit-sdk-go/services/rabbitmq (#720)
  * chore(deps): bump renovatebot/github-action from 41.0.21 to
    41.0.22 (#712)
  * fix(deps): update stackit sdk modules (#717)
* Wed Apr 30 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.31.0:
  * docs: sort available services (#711)
  * chore(deps): update samuelmeuli/action-snapcraft action to v3
    (#710)
  * Fix: Exit less if an interrupt character is typed (#704)
  * chore(deps): bump renovatebot/github-action from 41.0.5 to
    41.0.21 (#705)
  * feat(github): enable dependabot for golang and gh actions
    (#703)
  * fix(deps): update module
    github.com/stackitcloud/stackit-sdk-go/services/observability
    to v0.5.0 (#701)
  * Feat/stackitcli 134 onboading alb service (#697)
  * fix(deps): update module
    github.com/stackitcloud/stackit-sdk-go/core to v0.17.1 (#699)
  * fix(image): Uefi flag cannot be set to false (#698)
  * feat: add completion to homebrew installation (#692)
  * fix(deps): update module golang.org/x/term to v0.31.0 (#689)
  * feat(network-interface): Extend list output to contain device
    and ipv4 (#695)
  * feat(ci): close stale PRs automatically (#693)
  * chore(doc): add documentation of release process (#687)
* Tue Apr  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.30.0:
  * fix: project list command does not work with service account
    (#691)
  * fix(deps): update stackit sdk modules (#684)
  * fix(deps): update module golang.org/x/oauth2 to v0.29.0 (#688)
  * fix(deps): update module golang.org/x/text to v0.24.0 (#690)
  * feat(ci): enusure docs are up-to-date for PRs (#686)
  * feat(auth): Introduce possibility to use an environment
    variable to authenticate (#682)
  * chore: upgraded go version (#685)
  * chore(observability): remove argus alias and warning in readme
    (#683)
  * chore(sqlserverflex): show how to get flavors in create
    instance example (#679)
  * fix(deps): update stackit sdk modules (#680)
  * fix(deps): update kubernetes packages to v0.32.3 (#677)
  * fix(deps): update module golang.org/x/oauth2 to v0.28.0 (#632)
  * fix(deps): update module golang.org/x/text to v0.23.0 (#644)
  * fix(deps): update module golang.org/x/mod to v0.24.0 (#642)
  * fix(deps): update module golang.org/x/term to v0.30.0 (#643)
  * fix(deps): update module github.com/goccy/go-yaml to v1.17.1
    (#678)
  * chore(github): add issue templates (#675)
  * fix(server): List also delete_on_termination (#673)
  * chore(github): add pull request template (#671)
  * fix(deps): update stackit sdk modules (#672)
  * fix(deps): update module github.com/spf13/viper to v1.20.1
    (#665)
  * chore(doc): update installation docs (#668)
  * chore: update stackit logo in README.md (#670)
* Thu Mar 27 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.29.0:
  * fix(auth): print token to stdout on get-access-token cmd (#669)
  * feat(serverbackup): Region adjustment (#667)
  * chore(server): regional adjustment for server update (#662)
  * fix(deps): update module
    github.com/stackitcloud/stackit-sdk-go/core to v0.16.2 (#666)
  * chore: add make option to create test coverage reports (#659)
* Wed Mar 26 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.28.0:
  * fix(deps): update stackit sdk modules (#658)
  * fix(deps): update module github.com/golang-jwt/jwt/v5 to v5.2.2
    [security] (#663)
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.27.0:
  * replace STACKIT logo on login page (#661)
  * chore(server): regional adjustment for runcommand (#660)
  * fix(deps): update module github.com/spf13/viper to v1.20.0
    (#650)
  * fix(sqlserverflex): require roles flag on user creation (#657)
  * chore(loadbalancer): regional adjustment (#652)
  * fix(deps): update module github.com/goccy/go-yaml to v1.16.0
    (#651)
  * fix(sqlserver): remove region configuration from client (#656)
  * chore(doc): add github issue note and docs link to readme
    (#655)
  * feat(serviceenablement): Region adjustment (#649)
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.26.0:
  * feat(postgresql): Region adjustment (#648)
  * feat(sqlserverflex): region adjustment (#639)
  * chore(project): Add nil pointer checks and tests for the
    outputResult functions (#622)
  * chore (postgresflex): Fix potential nil pointer and add test
    cases (#626)
  * Feat/stackitcli 117 move iaa s beta commonds to top level
    (#611)
  * Redis: Add nil checks and testcases for output functions (#646)
  * RabbitMQ: Nil checks and testcases for output functions (#645)
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.25.0:
  * fix(deps): update stackit sdk modules (#637)
  * fix(deps): update module github.com/jedib0t/go-pretty/v6 to
    v6.6.7 (#640)
  * fix(secrets-manager): add nil pointer checks for cmd outputs
    (#633)
  * fix(ske): add nil pointer checks for cmd outputs (#634)
  * fix(service-account): add nil pointer checks for cmd outputs
    (#635)
  * chore(load-balancer): Add nil pointer checks and tests for the
    outputResult functions (#624)
  * chore(sqlserverflex): Add nil pointer checks and tests for the
    outputResult functions (#625)
  * chore(volume): Add nil pointer checks and tests for
    outputResult functions (#623)
  * fix(mariadb): add nil pointer checks for cmd outputs (#628)
  * Fix/network area and network missing label selector (#627)
  * fix(deps): update module github.com/google/go-cmp to v0.7.0
    (#630)
  * fix(deps): update stackit sdk modules (#631)
  * chore(iaas): remove unneeded todo comment (#629)
  * fix: stackit beta network-area commands - add nil pointer
    checks and tests for the outputResult functions (#606)
  * fix(logme): add nil pointer checks for cmd outputs (#619)
  * Allow workaround if no browser can be opened (#603)
  * chore(curl): Add nil pointer checks and tests for the
    outputResult functions (#620)
  * chore(config): Add nil pointer checks and tests for the
    outputResult functions (#621)
  * chore(dns): Add nil pointer checks and tests for outputResult
    functions (#618)
  * chore(security-group): Add nil pointer checks and tests for the
    outputResult functions (#613)
  * fix(observability): add nil pointer checks for cmd outputs
    (#617)
  * fix(mongodbflex): add nil pointer checks for cmd outputs (#614)
  * fix(opensearch): add nil pointer checks for cmd outputs (#616)
  * fix(organization): add nil pointer checks for cmd outputs
    (#615)
  * fix: stackit beta network-interface commands - add nil pointer
    checks and tests for the outputResult functions (#605)
  * fix: stackit beta network commands - add nil pointer checks and
    tests for the outputResult functions (#607)
  * fix: stackit beta image commands - add nil pointer checks and
    tests for the outputResult functions (#608)
  * fix: stackit beta public-ip commands - add nil pointer checks
    and tests for the outputResult functions (#609)
  * fix: stackit beta quota command - add nil pointer checks and
    tests for the outputResult functions (#610)
  * fix(object-storage): add nil pointer checks for cmd outputs
    (#612)
  * fix: `stackit beta server` commands - add nil pointer checks
    and tests for the outputResult functions (#604)
  * fix(deps): update module github.com/spf13/cobra to v1.9.1
    (#602)
  * fix(deps): update module github.com/goccy/go-yaml to v1.15.23
    (#601)
  * feat(auth): add get-access-token cmd (#598)
* Fri Feb 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package stackit-cli: command-line interface to manage STACKIT
  resources
